@@ -191,11 +191,11 @@ ltsReg.default <- function (x, y, intercept = TRUE,
     storage.mode(y) <- "double"
     storage.mode(x) <- "double"
     if (!oneD) {
-	constantcolom <- function(x) {
+	is.const <- function(x) {
 	    c1 <- range(x)
 	    c1[1] == c1[2]
 	}
-	if (sum(apply(x, 2, constantcolom)) > 0)
+	if (any(apply(x, 2, is.const)))
 	    stop("There is at least one constant column. Remove it and set intercept=TRUE")
     }
 
@@ -367,8 +367,10 @@ ltsReg.default <- function (x, y, intercept = TRUE,
 	    z <- .fastlts(x, y, h, nsamp, intercept, adjust, trace=as.integer(trace))
 
 	    ## vt:: lm.fit.qr == lm.fit(...,method=qr,...)
-	    ##	cf <- lm.fit.qr(x[z$inbest, , drop = FALSE], y[z$inbest])$coef
 	    cf <- lm.fit(x[z$inbest, , drop = FALSE], y[z$inbest])$coef
+	    if(any(ic <- is.na(cf)))
+		stop(gettextf("NA coefficient (at %s) from \"best\" subset",
+			      paste(which(ic), collapse =",")))
 	    ans$best <- sort(z$inbest)
 	    fitted <- x %*% cf
 	    resid <- y - fitted
@@ -380,7 +382,7 @@ ltsReg.default <- function (x, y, intercept = TRUE,
 	    correct <- if(use.correction)
 		LTScnp2(p, intercept = intercept, n, alpha) else 1
 	    raw.cnp2[2] <- correct
-	    s0 <- sqrt((1/h) * sum(sort(resid^2, partial = h)[1:h]))
+	    s0 <- sqrt(mean(sort(resid^2, partial = h)[1:h]))
 	    sh0 <- s0
 	    qn.q <- qnorm((h + n)/ (2 * n))
 	    s0 <- s0 / sqrt(1 - (2 * n)/(h / qn.q) * dnorm(qn.q)) * correct
@@ -824,21 +826,20 @@ LTScnp2.rew <- function(p, intercept = intercept, n, alpha)
     weights <- aw2 <- aw <- residu <- yy <-
 	nmahad <- ndist <- am <- am2 <- slutn <- double(n)
 
-    .Fortran(rfltsreg,
+    .Fortran(rfltsreg, ## -> ../src/rfltsreg.f
 	     xy = xy,
 	     n,
 	     p,
-	     h.alph,
-	     nsamp,
+	     h.alph, # = nhalff
+	     nsamp,  # = krep
 
-	     inbest = rep.int(10000L, h.alph),
+	     inbest = integer(h.alph),
 	     objfct = 0.,# double
 
 	     intercept = as.integer(intercept),
 	     intadjust = as.integer(adjust),
 	     nvad = as.integer(p1),
 	     datt = matrix(0., ncol = p1, nrow = n),
-	     integer(1),## << 'seed' no longer used -- FIXME
 	     weights,
 	     temp,
 	     index1,
